@@ -3,9 +3,11 @@ Main interface for comprehendmedical service type definitions.
 
 Usage::
 
-    from mypy_boto3.comprehendmedical.type_defs import ComprehendMedicalAsyncJobFilterTypeDef
+    ```python
+    from mypy_boto3_comprehendmedical.type_defs import AttributeTypeDef
 
-    data: ComprehendMedicalAsyncJobFilterTypeDef = {...}
+    data: AttributeTypeDef = {...}
+    ```
 """
 from datetime import datetime
 import sys
@@ -22,30 +24,30 @@ else:
 
 
 __all__ = (
-    "ComprehendMedicalAsyncJobFilterTypeDef",
+    "AttributeTypeDef",
+    "ComprehendMedicalAsyncJobPropertiesTypeDef",
+    "EntityTypeDef",
+    "ICD10CMAttributeTypeDef",
+    "ICD10CMConceptTypeDef",
+    "ICD10CMEntityTypeDef",
+    "ICD10CMTraitTypeDef",
     "InputDataConfigTypeDef",
     "OutputDataConfigTypeDef",
-    "ComprehendMedicalAsyncJobPropertiesTypeDef",
+    "RxNormAttributeTypeDef",
+    "RxNormConceptTypeDef",
+    "RxNormEntityTypeDef",
+    "RxNormTraitTypeDef",
+    "TraitTypeDef",
+    "UnmappedAttributeTypeDef",
+    "ComprehendMedicalAsyncJobFilterTypeDef",
     "DescribeEntitiesDetectionV2JobResponseTypeDef",
     "DescribeICD10CMInferenceJobResponseTypeDef",
     "DescribePHIDetectionJobResponseTypeDef",
     "DescribeRxNormInferenceJobResponseTypeDef",
-    "TraitTypeDef",
-    "AttributeTypeDef",
-    "EntityTypeDef",
-    "UnmappedAttributeTypeDef",
     "DetectEntitiesResponseTypeDef",
     "DetectEntitiesV2ResponseTypeDef",
     "DetectPHIResponseTypeDef",
-    "ICD10CMTraitTypeDef",
-    "ICD10CMAttributeTypeDef",
-    "ICD10CMConceptTypeDef",
-    "ICD10CMEntityTypeDef",
     "InferICD10CMResponseTypeDef",
-    "RxNormTraitTypeDef",
-    "RxNormAttributeTypeDef",
-    "RxNormConceptTypeDef",
-    "RxNormEntityTypeDef",
     "InferRxNormResponseTypeDef",
     "ListEntitiesDetectionV2JobsResponseTypeDef",
     "ListICD10CMInferenceJobsResponseTypeDef",
@@ -61,104 +63,6 @@ __all__ = (
     "StopRxNormInferenceJobResponseTypeDef",
 )
 
-ComprehendMedicalAsyncJobFilterTypeDef = TypedDict(
-    "ComprehendMedicalAsyncJobFilterTypeDef",
-    {
-        "JobName": str,
-        "JobStatus": Literal[
-            "SUBMITTED",
-            "IN_PROGRESS",
-            "COMPLETED",
-            "PARTIAL_SUCCESS",
-            "FAILED",
-            "STOP_REQUESTED",
-            "STOPPED",
-        ],
-        "SubmitTimeBefore": datetime,
-        "SubmitTimeAfter": datetime,
-    },
-    total=False,
-)
-
-_RequiredInputDataConfigTypeDef = TypedDict("_RequiredInputDataConfigTypeDef", {"S3Bucket": str})
-_OptionalInputDataConfigTypeDef = TypedDict(
-    "_OptionalInputDataConfigTypeDef", {"S3Key": str}, total=False
-)
-
-
-class InputDataConfigTypeDef(_RequiredInputDataConfigTypeDef, _OptionalInputDataConfigTypeDef):
-    pass
-
-
-_RequiredOutputDataConfigTypeDef = TypedDict("_RequiredOutputDataConfigTypeDef", {"S3Bucket": str})
-_OptionalOutputDataConfigTypeDef = TypedDict(
-    "_OptionalOutputDataConfigTypeDef", {"S3Key": str}, total=False
-)
-
-
-class OutputDataConfigTypeDef(_RequiredOutputDataConfigTypeDef, _OptionalOutputDataConfigTypeDef):
-    pass
-
-
-ComprehendMedicalAsyncJobPropertiesTypeDef = TypedDict(
-    "ComprehendMedicalAsyncJobPropertiesTypeDef",
-    {
-        "JobId": str,
-        "JobName": str,
-        "JobStatus": Literal[
-            "SUBMITTED",
-            "IN_PROGRESS",
-            "COMPLETED",
-            "PARTIAL_SUCCESS",
-            "FAILED",
-            "STOP_REQUESTED",
-            "STOPPED",
-        ],
-        "Message": str,
-        "SubmitTime": datetime,
-        "EndTime": datetime,
-        "ExpirationTime": datetime,
-        "InputDataConfig": InputDataConfigTypeDef,
-        "OutputDataConfig": OutputDataConfigTypeDef,
-        "LanguageCode": Literal["en"],
-        "DataAccessRoleArn": str,
-        "ManifestFilePath": str,
-        "KMSKey": str,
-        "ModelVersion": str,
-    },
-    total=False,
-)
-
-DescribeEntitiesDetectionV2JobResponseTypeDef = TypedDict(
-    "DescribeEntitiesDetectionV2JobResponseTypeDef",
-    {"ComprehendMedicalAsyncJobProperties": ComprehendMedicalAsyncJobPropertiesTypeDef},
-    total=False,
-)
-
-DescribeICD10CMInferenceJobResponseTypeDef = TypedDict(
-    "DescribeICD10CMInferenceJobResponseTypeDef",
-    {"ComprehendMedicalAsyncJobProperties": ComprehendMedicalAsyncJobPropertiesTypeDef},
-    total=False,
-)
-
-DescribePHIDetectionJobResponseTypeDef = TypedDict(
-    "DescribePHIDetectionJobResponseTypeDef",
-    {"ComprehendMedicalAsyncJobProperties": ComprehendMedicalAsyncJobPropertiesTypeDef},
-    total=False,
-)
-
-DescribeRxNormInferenceJobResponseTypeDef = TypedDict(
-    "DescribeRxNormInferenceJobResponseTypeDef",
-    {"ComprehendMedicalAsyncJobProperties": ComprehendMedicalAsyncJobPropertiesTypeDef},
-    total=False,
-)
-
-TraitTypeDef = TypedDict(
-    "TraitTypeDef",
-    {"Name": Literal["SIGN", "SYMPTOM", "DIAGNOSIS", "NEGATION"], "Score": float},
-    total=False,
-)
-
 AttributeTypeDef = TypedDict(
     "AttributeTypeDef",
     {
@@ -231,7 +135,36 @@ AttributeTypeDef = TypedDict(
             "ANATOMY",
             "TIME_EXPRESSION",
         ],
-        "Traits": List[TraitTypeDef],
+        "Traits": List["TraitTypeDef"],
+    },
+    total=False,
+)
+
+ComprehendMedicalAsyncJobPropertiesTypeDef = TypedDict(
+    "ComprehendMedicalAsyncJobPropertiesTypeDef",
+    {
+        "JobId": str,
+        "JobName": str,
+        "JobStatus": Literal[
+            "SUBMITTED",
+            "IN_PROGRESS",
+            "COMPLETED",
+            "PARTIAL_SUCCESS",
+            "FAILED",
+            "STOP_REQUESTED",
+            "STOPPED",
+        ],
+        "Message": str,
+        "SubmitTime": datetime,
+        "EndTime": datetime,
+        "ExpirationTime": datetime,
+        "InputDataConfig": "InputDataConfigTypeDef",
+        "OutputDataConfig": "OutputDataConfigTypeDef",
+        "LanguageCode": Literal["en"],
+        "DataAccessRoleArn": str,
+        "ManifestFilePath": str,
+        "KMSKey": str,
+        "ModelVersion": str,
     },
     total=False,
 )
@@ -288,81 +221,12 @@ EntityTypeDef = TypedDict(
             "TIME_TO_PROCEDURE_NAME",
             "TIME_TO_TREATMENT_NAME",
         ],
-        "Traits": List[TraitTypeDef],
-        "Attributes": List[AttributeTypeDef],
+        "Traits": List["TraitTypeDef"],
+        "Attributes": List["AttributeTypeDef"],
     },
     total=False,
 )
 
-UnmappedAttributeTypeDef = TypedDict(
-    "UnmappedAttributeTypeDef",
-    {
-        "Type": Literal[
-            "MEDICATION",
-            "MEDICAL_CONDITION",
-            "PROTECTED_HEALTH_INFORMATION",
-            "TEST_TREATMENT_PROCEDURE",
-            "ANATOMY",
-            "TIME_EXPRESSION",
-        ],
-        "Attribute": AttributeTypeDef,
-    },
-    total=False,
-)
-
-_RequiredDetectEntitiesResponseTypeDef = TypedDict(
-    "_RequiredDetectEntitiesResponseTypeDef", {"Entities": List[EntityTypeDef], "ModelVersion": str}
-)
-_OptionalDetectEntitiesResponseTypeDef = TypedDict(
-    "_OptionalDetectEntitiesResponseTypeDef",
-    {"UnmappedAttributes": List[UnmappedAttributeTypeDef], "PaginationToken": str},
-    total=False,
-)
-
-
-class DetectEntitiesResponseTypeDef(
-    _RequiredDetectEntitiesResponseTypeDef, _OptionalDetectEntitiesResponseTypeDef
-):
-    pass
-
-
-_RequiredDetectEntitiesV2ResponseTypeDef = TypedDict(
-    "_RequiredDetectEntitiesV2ResponseTypeDef",
-    {"Entities": List[EntityTypeDef], "ModelVersion": str},
-)
-_OptionalDetectEntitiesV2ResponseTypeDef = TypedDict(
-    "_OptionalDetectEntitiesV2ResponseTypeDef",
-    {"UnmappedAttributes": List[UnmappedAttributeTypeDef], "PaginationToken": str},
-    total=False,
-)
-
-
-class DetectEntitiesV2ResponseTypeDef(
-    _RequiredDetectEntitiesV2ResponseTypeDef, _OptionalDetectEntitiesV2ResponseTypeDef
-):
-    pass
-
-
-_RequiredDetectPHIResponseTypeDef = TypedDict(
-    "_RequiredDetectPHIResponseTypeDef", {"Entities": List[EntityTypeDef], "ModelVersion": str}
-)
-_OptionalDetectPHIResponseTypeDef = TypedDict(
-    "_OptionalDetectPHIResponseTypeDef", {"PaginationToken": str}, total=False
-)
-
-
-class DetectPHIResponseTypeDef(
-    _RequiredDetectPHIResponseTypeDef, _OptionalDetectPHIResponseTypeDef
-):
-    pass
-
-
-ICD10CMTraitTypeDef = TypedDict(
-    "ICD10CMTraitTypeDef",
-    {"Name": Literal["NEGATION", "DIAGNOSIS", "SIGN", "SYMPTOM"], "Score": float},
-    total=False,
-)
-
 ICD10CMAttributeTypeDef = TypedDict(
     "ICD10CMAttributeTypeDef",
     {
@@ -373,7 +237,7 @@ ICD10CMAttributeTypeDef = TypedDict(
         "BeginOffset": int,
         "EndOffset": int,
         "Text": str,
-        "Traits": List[ICD10CMTraitTypeDef],
+        "Traits": List["ICD10CMTraitTypeDef"],
     },
     total=False,
 )
@@ -392,33 +256,39 @@ ICD10CMEntityTypeDef = TypedDict(
         "Score": float,
         "BeginOffset": int,
         "EndOffset": int,
-        "Attributes": List[ICD10CMAttributeTypeDef],
-        "Traits": List[ICD10CMTraitTypeDef],
-        "ICD10CMConcepts": List[ICD10CMConceptTypeDef],
+        "Attributes": List["ICD10CMAttributeTypeDef"],
+        "Traits": List["ICD10CMTraitTypeDef"],
+        "ICD10CMConcepts": List["ICD10CMConceptTypeDef"],
     },
     total=False,
 )
 
-_RequiredInferICD10CMResponseTypeDef = TypedDict(
-    "_RequiredInferICD10CMResponseTypeDef", {"Entities": List[ICD10CMEntityTypeDef]}
-)
-_OptionalInferICD10CMResponseTypeDef = TypedDict(
-    "_OptionalInferICD10CMResponseTypeDef",
-    {"PaginationToken": str, "ModelVersion": str},
+ICD10CMTraitTypeDef = TypedDict(
+    "ICD10CMTraitTypeDef",
+    {"Name": Literal["NEGATION", "DIAGNOSIS", "SIGN", "SYMPTOM"], "Score": float},
     total=False,
 )
 
+_RequiredInputDataConfigTypeDef = TypedDict("_RequiredInputDataConfigTypeDef", {"S3Bucket": str})
+_OptionalInputDataConfigTypeDef = TypedDict(
+    "_OptionalInputDataConfigTypeDef", {"S3Key": str}, total=False
+)
 
-class InferICD10CMResponseTypeDef(
-    _RequiredInferICD10CMResponseTypeDef, _OptionalInferICD10CMResponseTypeDef
-):
+
+class InputDataConfigTypeDef(_RequiredInputDataConfigTypeDef, _OptionalInputDataConfigTypeDef):
     pass
 
 
-RxNormTraitTypeDef = TypedDict(
-    "RxNormTraitTypeDef", {"Name": Literal["NEGATION"], "Score": float}, total=False
+_RequiredOutputDataConfigTypeDef = TypedDict("_RequiredOutputDataConfigTypeDef", {"S3Bucket": str})
+_OptionalOutputDataConfigTypeDef = TypedDict(
+    "_OptionalOutputDataConfigTypeDef", {"S3Key": str}, total=False
 )
 
+
+class OutputDataConfigTypeDef(_RequiredOutputDataConfigTypeDef, _OptionalOutputDataConfigTypeDef):
+    pass
+
+
 RxNormAttributeTypeDef = TypedDict(
     "RxNormAttributeTypeDef",
     {
@@ -431,7 +301,7 @@ RxNormAttributeTypeDef = TypedDict(
         "BeginOffset": int,
         "EndOffset": int,
         "Text": str,
-        "Traits": List[RxNormTraitTypeDef],
+        "Traits": List["RxNormTraitTypeDef"],
     },
     total=False,
 )
@@ -450,15 +320,148 @@ RxNormEntityTypeDef = TypedDict(
         "Score": float,
         "BeginOffset": int,
         "EndOffset": int,
-        "Attributes": List[RxNormAttributeTypeDef],
-        "Traits": List[RxNormTraitTypeDef],
-        "RxNormConcepts": List[RxNormConceptTypeDef],
+        "Attributes": List["RxNormAttributeTypeDef"],
+        "Traits": List["RxNormTraitTypeDef"],
+        "RxNormConcepts": List["RxNormConceptTypeDef"],
     },
     total=False,
 )
 
+RxNormTraitTypeDef = TypedDict(
+    "RxNormTraitTypeDef", {"Name": Literal["NEGATION"], "Score": float}, total=False
+)
+
+TraitTypeDef = TypedDict(
+    "TraitTypeDef",
+    {"Name": Literal["SIGN", "SYMPTOM", "DIAGNOSIS", "NEGATION"], "Score": float},
+    total=False,
+)
+
+UnmappedAttributeTypeDef = TypedDict(
+    "UnmappedAttributeTypeDef",
+    {
+        "Type": Literal[
+            "MEDICATION",
+            "MEDICAL_CONDITION",
+            "PROTECTED_HEALTH_INFORMATION",
+            "TEST_TREATMENT_PROCEDURE",
+            "ANATOMY",
+            "TIME_EXPRESSION",
+        ],
+        "Attribute": "AttributeTypeDef",
+    },
+    total=False,
+)
+
+ComprehendMedicalAsyncJobFilterTypeDef = TypedDict(
+    "ComprehendMedicalAsyncJobFilterTypeDef",
+    {
+        "JobName": str,
+        "JobStatus": Literal[
+            "SUBMITTED",
+            "IN_PROGRESS",
+            "COMPLETED",
+            "PARTIAL_SUCCESS",
+            "FAILED",
+            "STOP_REQUESTED",
+            "STOPPED",
+        ],
+        "SubmitTimeBefore": datetime,
+        "SubmitTimeAfter": datetime,
+    },
+    total=False,
+)
+
+DescribeEntitiesDetectionV2JobResponseTypeDef = TypedDict(
+    "DescribeEntitiesDetectionV2JobResponseTypeDef",
+    {"ComprehendMedicalAsyncJobProperties": "ComprehendMedicalAsyncJobPropertiesTypeDef"},
+    total=False,
+)
+
+DescribeICD10CMInferenceJobResponseTypeDef = TypedDict(
+    "DescribeICD10CMInferenceJobResponseTypeDef",
+    {"ComprehendMedicalAsyncJobProperties": "ComprehendMedicalAsyncJobPropertiesTypeDef"},
+    total=False,
+)
+
+DescribePHIDetectionJobResponseTypeDef = TypedDict(
+    "DescribePHIDetectionJobResponseTypeDef",
+    {"ComprehendMedicalAsyncJobProperties": "ComprehendMedicalAsyncJobPropertiesTypeDef"},
+    total=False,
+)
+
+DescribeRxNormInferenceJobResponseTypeDef = TypedDict(
+    "DescribeRxNormInferenceJobResponseTypeDef",
+    {"ComprehendMedicalAsyncJobProperties": "ComprehendMedicalAsyncJobPropertiesTypeDef"},
+    total=False,
+)
+
+_RequiredDetectEntitiesResponseTypeDef = TypedDict(
+    "_RequiredDetectEntitiesResponseTypeDef",
+    {"Entities": List["EntityTypeDef"], "ModelVersion": str},
+)
+_OptionalDetectEntitiesResponseTypeDef = TypedDict(
+    "_OptionalDetectEntitiesResponseTypeDef",
+    {"UnmappedAttributes": List["UnmappedAttributeTypeDef"], "PaginationToken": str},
+    total=False,
+)
+
+
+class DetectEntitiesResponseTypeDef(
+    _RequiredDetectEntitiesResponseTypeDef, _OptionalDetectEntitiesResponseTypeDef
+):
+    pass
+
+
+_RequiredDetectEntitiesV2ResponseTypeDef = TypedDict(
+    "_RequiredDetectEntitiesV2ResponseTypeDef",
+    {"Entities": List["EntityTypeDef"], "ModelVersion": str},
+)
+_OptionalDetectEntitiesV2ResponseTypeDef = TypedDict(
+    "_OptionalDetectEntitiesV2ResponseTypeDef",
+    {"UnmappedAttributes": List["UnmappedAttributeTypeDef"], "PaginationToken": str},
+    total=False,
+)
+
+
+class DetectEntitiesV2ResponseTypeDef(
+    _RequiredDetectEntitiesV2ResponseTypeDef, _OptionalDetectEntitiesV2ResponseTypeDef
+):
+    pass
+
+
+_RequiredDetectPHIResponseTypeDef = TypedDict(
+    "_RequiredDetectPHIResponseTypeDef", {"Entities": List["EntityTypeDef"], "ModelVersion": str}
+)
+_OptionalDetectPHIResponseTypeDef = TypedDict(
+    "_OptionalDetectPHIResponseTypeDef", {"PaginationToken": str}, total=False
+)
+
+
+class DetectPHIResponseTypeDef(
+    _RequiredDetectPHIResponseTypeDef, _OptionalDetectPHIResponseTypeDef
+):
+    pass
+
+
+_RequiredInferICD10CMResponseTypeDef = TypedDict(
+    "_RequiredInferICD10CMResponseTypeDef", {"Entities": List["ICD10CMEntityTypeDef"]}
+)
+_OptionalInferICD10CMResponseTypeDef = TypedDict(
+    "_OptionalInferICD10CMResponseTypeDef",
+    {"PaginationToken": str, "ModelVersion": str},
+    total=False,
+)
+
+
+class InferICD10CMResponseTypeDef(
+    _RequiredInferICD10CMResponseTypeDef, _OptionalInferICD10CMResponseTypeDef
+):
+    pass
+
+
 _RequiredInferRxNormResponseTypeDef = TypedDict(
-    "_RequiredInferRxNormResponseTypeDef", {"Entities": List[RxNormEntityTypeDef]}
+    "_RequiredInferRxNormResponseTypeDef", {"Entities": List["RxNormEntityTypeDef"]}
 )
 _OptionalInferRxNormResponseTypeDef = TypedDict(
     "_OptionalInferRxNormResponseTypeDef",
@@ -476,7 +479,9 @@ class InferRxNormResponseTypeDef(
 ListEntitiesDetectionV2JobsResponseTypeDef = TypedDict(
     "ListEntitiesDetectionV2JobsResponseTypeDef",
     {
-        "ComprehendMedicalAsyncJobPropertiesList": List[ComprehendMedicalAsyncJobPropertiesTypeDef],
+        "ComprehendMedicalAsyncJobPropertiesList": List[
+            "ComprehendMedicalAsyncJobPropertiesTypeDef"
+        ],
         "NextToken": str,
     },
     total=False,
@@ -485,7 +490,9 @@ ListEntitiesDetectionV2JobsResponseTypeDef = TypedDict(
 ListICD10CMInferenceJobsResponseTypeDef = TypedDict(
     "ListICD10CMInferenceJobsResponseTypeDef",
     {
-        "ComprehendMedicalAsyncJobPropertiesList": List[ComprehendMedicalAsyncJobPropertiesTypeDef],
+        "ComprehendMedicalAsyncJobPropertiesList": List[
+            "ComprehendMedicalAsyncJobPropertiesTypeDef"
+        ],
         "NextToken": str,
     },
     total=False,
@@ -494,7 +501,9 @@ ListICD10CMInferenceJobsResponseTypeDef = TypedDict(
 ListPHIDetectionJobsResponseTypeDef = TypedDict(
     "ListPHIDetectionJobsResponseTypeDef",
     {
-        "ComprehendMedicalAsyncJobPropertiesList": List[ComprehendMedicalAsyncJobPropertiesTypeDef],
+        "ComprehendMedicalAsyncJobPropertiesList": List[
+            "ComprehendMedicalAsyncJobPropertiesTypeDef"
+        ],
         "NextToken": str,
     },
     total=False,
@@ -503,7 +512,9 @@ ListPHIDetectionJobsResponseTypeDef = TypedDict(
 ListRxNormInferenceJobsResponseTypeDef = TypedDict(
     "ListRxNormInferenceJobsResponseTypeDef",
     {
-        "ComprehendMedicalAsyncJobPropertiesList": List[ComprehendMedicalAsyncJobPropertiesTypeDef],
+        "ComprehendMedicalAsyncJobPropertiesList": List[
+            "ComprehendMedicalAsyncJobPropertiesTypeDef"
+        ],
         "NextToken": str,
     },
     total=False,
